package javax.swing;

import java.awt.Window;
import java.awt.event.ComponentEvent;
import java.awt.event.ComponentAdapter;
import java.awt.event.WindowEvent;
import java.io.Serializable;
import java.awt.event.WindowAdapter;
import java.awt.Container;
import java.util.Locale;
import sun.swing.SwingUtilities2;
import java.awt.event.ActionEvent;
import java.awt.FlowLayout;
import java.awt.BorderLayout;
import java.awt.Frame;
import java.awt.HeadlessException;
import java.awt.event.ActionListener;
import java.awt.Component;
import java.awt.Dialog;
import java.awt.Color;

class ColorChooserDialog extends JDialog
{
    private Color initialColor;
    private JColorChooser chooserPane;
    private JButton cancelButton;
    
    public ColorChooserDialog(Dialog dialog, String s, boolean b, Component component, JColorChooser colorChooser, ActionListener actionListener, ActionListener actionListener2) throws HeadlessException {
        super(dialog, s, b);
        this.initColorChooserDialog(component, colorChooser, actionListener, actionListener2);
    }
    
    public ColorChooserDialog(Frame frame, String s, boolean b, Component component, JColorChooser colorChooser, ActionListener actionListener, ActionListener actionListener2) throws HeadlessException {
        super(frame, s, b);
        this.initColorChooserDialog(component, colorChooser, actionListener, actionListener2);
    }
    
    protected void initColorChooserDialog(Component locationRelativeTo, JColorChooser colorChooser, ActionListener actionListener, ActionListener actionListener2) {
        this.chooserPane = colorChooser;
        Locale locale = this.getLocale();
        String string = UIManager.getString("ColorChooser.okText", locale);
        String string2 = UIManager.getString("ColorChooser.cancelText", locale);
        String string3 = UIManager.getString("ColorChooser.resetText", locale);
        Container contentPane = this.getContentPane();
        contentPane.setLayout(new BorderLayout());
        contentPane.add(colorChooser, "Center");
        JPanel comp = new JPanel();
        comp.setLayout(new FlowLayout(1));
        JButton button = new JButton(string);
        this.getRootPane().setDefaultButton(button);
        button.getAccessibleContext().setAccessibleDescription(string);
        button.setActionCommand("OK");
        button.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent actionEvent) {
                ColorChooserDialog.this.hide();
            }
        });
        if (actionListener != null) {
            button.addActionListener(actionListener);
        }
        comp.add(button);
        this.cancelButton = new JButton(string2);
        this.cancelButton.getAccessibleContext().setAccessibleDescription(string2);
        AbstractAction abstractAction = new AbstractAction() {
            @Override
            public void actionPerformed(ActionEvent actionEvent) {
                ((AbstractButton)actionEvent.getSource()).fireActionPerformed(actionEvent);
            }
        };
        KeyStroke keyStroke = KeyStroke.getKeyStroke(27, 0);
        InputMap inputMap = this.cancelButton.getInputMap(2);
        ActionMap actionMap = this.cancelButton.getActionMap();
        if (inputMap != null && actionMap != null) {
            inputMap.put(keyStroke, "cancel");
            actionMap.put("cancel", abstractAction);
        }
        this.cancelButton.setActionCommand("cancel");
        this.cancelButton.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent actionEvent) {
                ColorChooserDialog.this.hide();
            }
        });
        if (actionListener2 != null) {
            this.cancelButton.addActionListener(actionListener2);
        }
        comp.add(this.cancelButton);
        JButton comp2 = new JButton(string3);
        comp2.getAccessibleContext().setAccessibleDescription(string3);
        comp2.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent actionEvent) {
                ColorChooserDialog.this.reset();
            }
        });
        int uiDefaultsInt = SwingUtilities2.getUIDefaultsInt("ColorChooser.resetMnemonic", locale, -1);
        if (uiDefaultsInt != -1) {
            comp2.setMnemonic(uiDefaultsInt);
        }
        comp.add(comp2);
        contentPane.add(comp, "South");
        if (JDialog.isDefaultLookAndFeelDecorated() && UIManager.getLookAndFeel().getSupportsWindowDecorations()) {
            this.getRootPane().setWindowDecorationStyle(5);
        }
        this.applyComponentOrientation(((locationRelativeTo == null) ? this.getRootPane() : locationRelativeTo).getComponentOrientation());
        this.pack();
        this.setLocationRelativeTo(locationRelativeTo);
        this.addWindowListener(new ColorChooserDialog.Closer());
    }
    
    @Override
    public void show() {
        this.initialColor = this.chooserPane.getColor();
        super.show();
    }
    
    public void reset() {
        this.chooserPane.setColor(this.initialColor);
    }
    
    class Closer extends WindowAdapter implements Serializable
    {
        @Override
        public void windowClosing(WindowEvent windowEvent) {
            ColorChooserDialog.this.cancelButton.doClick(0);
            windowEvent.getWindow().hide();
        }
    }
    
    static class DisposeOnClose extends ComponentAdapter implements Serializable
    {
        @Override
        public void componentHidden(ComponentEvent componentEvent) {
            ((Window)componentEvent.getComponent()).dispose();
        }
    }
}
